==> haskell-hls-alternate-number-format-plugin-2.0.0.0-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.0.0.0-KyIR8h91HefEvSQOQruFGz

key:
    hls-alternate-number-format-plugin-2.0.0.0-KyIR8h91HefEvSQOQruFGz

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  fdf5b045a51e27b05bd3633dabef0e9e
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.0.0.0-KyIR8h91HefEvSQOQruFGz

depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1 containers-0.6.7
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-boot-th-9.4.8
    ghcide-2.0.0.0-3DlUhCtF16XEaV5TtFcT3J
    hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    hls-graph-2.0.0.0-6aKGFDEwcZ2Gewpz8C2a3M
    hls-plugin-api-2.0.0.0-BSQontPVPIA4EciidEETjs
    lens-5.2.3-DnVNcFpsuwMCXFWImXsY2L
    lsp-1.6.0.0-1RxTvmiJB0d2TzCGfgQy8D mtl-2.2.2
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hls-alternate-number-format-plugin-2.0.0.0-31-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-hls-alternate-number-format-plugin.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-alternate-number-format-plugin
version:              2.0.0.0
visibility:           public
id:
    hls-alternate-number-format-plugin-2.0.0.0-LWTWDpgzdZgFQeUiaitMgB

key:
    hls-alternate-number-format-plugin-2.0.0.0-LWTWDpgzdZgFQeUiaitMgB

license:              Apache-2.0
maintainer:           nicksuchecki@gmail.com
author:               Nick Suchecki
synopsis:
    Provide Alternate Number Formats plugin for Haskell Language Server

description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  740619a7c9611db289b45b98642b8bd5
exposed:              True
exposed-modules:
    Ide.Plugin.AlternateNumberFormat Ide.Plugin.Conversion

hidden-modules:       Ide.Plugin.Literals
import-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.0.0.0

library-dirs:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.0.0.0

library-dirs-static:
    /usr/lib/ghc-9.4.8/site-local/hls-alternate-number-format-plugin-2.0.0.0

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-alternate-number-format-plugin
hs-libraries:
    HShls-alternate-number-format-plugin-2.0.0.0-LWTWDpgzdZgFQeUiaitMgB

depends:
    aeson-2.1.2.1-G4Y2VMvw6jlHlUlOzfqhge base-4.17.2.1 containers-0.6.7
    extra-1.7.16-LRPaj0kKdYhA5DC3OzySjK ghc-boot-th-9.4.8
    ghcide-2.0.0.0-7O5MlhTeuzxG8Z14Vz3F5R
    hie-compat-0.3.0.0-CbBComUrkWGfIGRN5OUf4
    hls-graph-2.0.0.0-6aKGFDEwcZ2Gewpz8C2a3M
    hls-plugin-api-2.0.0.0-BSQontPVPIA4EciidEETjs
    lens-5.2.3-DnVNcFpsuwMCXFWImXsY2L
    lsp-1.6.0.0-1RxTvmiJB0d2TzCGfgQy8D mtl-2.2.2
    regex-tdfa-1.3.2.3-ATHs20GYS4zCnV1KwOyBL0
    syb-0.7.2.4-1AaSJ4gAQqF80sCpMGQHRf text-2.0.2
    unordered-containers-0.2.20-1zjZuvvQz6A9v2Utwl5wnX

haddock-interfaces:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html/hls-alternate-number-format-plugin.haddock

haddock-html:
    /usr/share/doc/haskell-hls-alternate-number-format-plugin/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
